Rev 1482: Add extra progress reporting. in http://people.samba.org/bzr/jelmer/bzr-svn/trunk

Jelmer Vernooij jelmer at samba.org
Mon Jul 21 20:42:35 BST 2008


At http://people.samba.org/bzr/jelmer/bzr-svn/trunk

------------------------------------------------------------
revno: 1482
revision-id: jelmer at samba.org-20080721194233-3mq364sd27qvy3cu
parent: jelmer at samba.org-20080719132004-3gc90uor5idh58b0
committer: Jelmer Vernooij <jelmer at samba.org>
branch nick: 0.4
timestamp: Mon 2008-07-21 21:42:33 +0200
message:
  Add extra progress reporting.
modified:
  repository.py                  repository.py-20060306123302-1f8c5069b3fe0265
=== modified file 'repository.py'
--- a/repository.py	2008-07-19 13:20:04 +0000
+++ b/repository.py	2008-07-21 19:42:33 +0000
@@ -738,8 +738,12 @@
 
     @needs_read_lock
     def find_tags(self, layout=None, revnum=None, project=None):
         """Find branches underneath this repository.
 
+        :param layout: Repository layout to use
+        :param revnum: Revision number in which to check, None for latest.
+        :param project: Name of the project to find tags for. None for all.
+        :return: Dictionary mapping tag names to revision ids.
         """
         if layout is None:
             layout = self.get_layout()
@@ -751,8 +755,10 @@
 
         tags = {}
         pb = ui.ui_factory.nested_progress_bar()
+        pb.update("finding tags")
         try:
             for project, bp, nick in layout.get_tags(revnum, project=project, pb=pb):
+                pb.tick()
                 npb = ui.ui_factory.nested_progress_bar()
                 try:
                     it = self.iter_changes(bp, revnum, mapping, pb=npb, limit=2)
@@ -738,8 +738,12 @@
     @needs_read_lock
     def find_tags(self, layout=None, revnum=None, project=None):
-        """Find branches underneath this repository.
+        """Find tags underneath this repository for the specified project.
 




More information about the bazaar-commits mailing list